v0.3.0
======

Features
--------

- :code:`llyfr open` now make use of a TUI powered by :code:`prompt_toolkit` to search
  for, select and open links in the database.

v0.2.0
======

Features
--------

- Add the ability to import a Sphinx documentation site based on its :code:`objects.inv`
  index.

v0.1.0
======

Initial version